@@ -1,13 +1,14 @@
 package Acme::CPANModules::WorkingWithTree;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-06'; # DATE
-our $DIST = 'Acme-CPANModules-WorkingWithTree'; # DIST
-our $VERSION = '0.005'; # VERSION
-
 use strict;
+use warnings;
 use Acme::CPANModulesUtil::Misc;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-07'; # DATE
+our $DIST = 'Acme-CPANModules-WorkingWithTree'; # DIST
+our $VERSION = '0.006'; # VERSION
+
 my $text = <<'_';
 **Basics**
 
@@ -58,7 +59,7 @@ Special kinds of trees: TODO.
 <pm:Role::TinyCommons::Tree::Node>, <pm:Role::TinyCommons::Tree::NodeMethods>.
 
 
-**Modules that produce or work with Role::TinyCommons::Tree-compliant tree objects**
+**Modules that produce or work with Role::TinyCommons::Tree::Node-compliant tree objects**
 
 <pm:Org::Parser>, <pm:Org::Parser::Tiny>.
 
@@ -93,7 +94,7 @@ Acme::CPANModules::WorkingWithTree - Working with tree data structure in Perl
 
 =head1 VERSION
 
-This document describes version 0.005 of Acme::CPANModules::WorkingWithTree (from Perl distribution Acme-CPANModules-WorkingWithTree), released on 2021-05-06.
+This document describes version 0.006 of Acme::CPANModules::WorkingWithTree (from Perl distribution Acme-CPANModules-WorkingWithTree), released on 2021-10-07.
 
 =head1 DESCRIPTION
 
@@ -140,7 +141,7 @@ B<Roles>
 
 L<Role::TinyCommons::Tree::Node>, L<Role::TinyCommons::Tree::NodeMethods>.
 
-B<Modules that produce or work with Role::TinyCommons::Tree-compliant tree objects>
+B<Modules that produce or work with Role::TinyCommons::Tree::Node-compliant tree objects>
 
 L<Org::Parser>, L<Org::Parser::Tiny>.
 
@@ -150,7 +151,7 @@ L<Data::CSel> and its related modules: L<App::htmlsel>, L<App::jsonsel>,
 L<App::orgsel>, L<App::podsel>, L<App::ppisel>, L<App::yamlsel>,
 L<App::CSelUtils>.
 
-=head1 ACME::CPANMODULES ENTRIES
+=head1 ACME::MODULES ENTRIES
 
 =over
 
@@ -231,8 +232,13 @@ document CPAN. See L<Acme::CPANModules> for more details.
 =head2 What are ways to use this Acme::CPANModules module?
 
 Aside from reading this Acme::CPANModules module's POD documentation, you can
-install all the listed modules (entries) using L<cpanmodules> CLI (from
-L<App::cpanmodules> distribution):
+install all the listed modules (entries) using L<cpanm-cpanmodules> script (from
+L<App::cpanm::cpanmodules> distribution):
+
+ % cpanm-cpanmodules -n WorkingWithTree
+
+Alternatively you can use the L<cpanmodules> CLI (from L<App::cpanmodules>
+distribution):
 
     % cpanmodules ls-entries WorkingWithTree | cpanm -n
 
@@ -247,6 +253,8 @@ or directly:
 This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
 result for C<lcpan related-mods> command when it comes to finding related
 modules for the modules listed in this Acme::CPANModules module.
+See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
+are found.
 
 =head1 HOMEPAGE
 
@@ -256,14 +264,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANM
 
 Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-WorkingWithTree>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModules-WorkingWithTree/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Acme::CPANModules> - about the Acme::CPANModules namespace
@@ -274,11 +274,36 @@ L<cpanmodules> - CLI tool to let you browse/view the lists
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-WorkingWithTree>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
